@@ -15,6 +15,8 @@ class DatabaseEntity(EntityBase):
         self.porta: int = None
         self.nome: str = None
         self.homologacao: bool = None
+        self.user: str = None 
+        self.password: str = None 
         # Atributos de auditoria
         self.criado_em: datetime.datetime = None
         self.criado_por: str = None
